@@ -1001,7 +1001,7 @@ g_local_file_query_filesystem_info (GFile         *file,
 #endif
     }
 #ifdef USE_STATFS
-#if defined(HAVE_STRUCT_STATFS_FS_TYPENAME)
+#if defined(HAVE_STRUCT_STATFS_F_FSTYPENAME)
   fstype = g_strdup(statfs_buffer.f_fstypename);
 #else
   fstype = get_fs_type (statfs_buffer.f_type);
@@ -1386,6 +1386,7 @@ get_parent (const char *path,
   if (strcmp (parent, ".") == 0 ||
       strcmp (parent, path_copy) == 0)
     {
+      g_free (parent);
       g_free (path_copy);
       return NULL;
     }
@@ -1576,6 +1577,79 @@ escape_trash_name (char *name)
   return g_string_free (str, FALSE);
 }
 
+gboolean
+_g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
+{
+  static gsize home_dev = 0;
+  char *topdir, *globaldir, *trashdir, *tmpname;
+  uid_t uid;
+  char uid_str[32];
+  struct stat global_stat, trash_stat;
+  gboolean res;
+  int statres;
+      
+  if (g_once_init_enter (&home_dev))
+    {
+      gsize setup_value = 0;
+      struct stat home_stat;
+      
+      g_stat (g_get_home_dir (), &home_stat);
+      setup_value = home_stat.st_dev;
+      g_once_init_leave (&home_dev, setup_value);
+    }
+
+  /* Assume we can trash to the home */
+  if (dir_dev == (dev_t)home_dev)
+    return TRUE;
+
+  topdir = find_mountpoint_for (dirname, dir_dev);
+  if (topdir == NULL)
+    return FALSE;
+
+  globaldir = g_build_filename (topdir, ".Trash", NULL); 
+  statres = g_lstat (globaldir, &global_stat);
+ if (g_lstat (globaldir, &global_stat) == 0 &&
+      S_ISDIR (global_stat.st_mode) &&
+      (global_stat.st_mode & S_ISVTX) != 0)
+    {
+      /* got a toplevel sysadmin created dir, assume we
+       * can trash to it (we should be able to create a dir)
+       * This fails for the FAT case where the ownership of
+       * that dir would be wrong though..
+       */
+      g_free (globaldir);
+      g_free (topdir);
+      return TRUE;
+    }
+  g_free (globaldir);
+
+  /* No global trash dir, or it failed the tests, fall back to $topdir/.Trash-$uid */
+  uid = geteuid ();
+  g_snprintf (uid_str, sizeof (uid_str), "%lu", (unsigned long) uid);
+  
+  tmpname = g_strdup_printf (".Trash-%s", uid_str);
+  trashdir = g_build_filename (topdir, tmpname, NULL);
+  g_free (tmpname);
+
+  if (g_lstat (trashdir, &trash_stat) == 0)
+    {
+      g_free (topdir);
+      g_free (trashdir);
+      return
+	S_ISDIR (trash_stat.st_mode) &&
+	trash_stat.st_uid == uid;
+    }
+  g_free (trashdir);
+
+  /* User specific trash didn't exist, can we create it? */
+  res = g_access (topdir, W_OK) == 0;
+  
+  g_free (topdir);
+  
+  return res;
+}
+
+
 static gboolean
 g_local_file_trash (GFile         *file,
 		    GCancellable  *cancellable,
@@ -1844,6 +1918,12 @@ g_local_file_trash (GFile         *file,
   return TRUE;
 }
 #else /* G_OS_WIN32 */
+gboolean
+_g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
+{
+  return FALSE;			/* XXX ??? */
+}
+
 static gboolean
 g_local_file_trash (GFile         *file,
 		    GCancellable  *cancellable,
@@ -1999,9 +2079,8 @@ g_local_file_move (GFile                  *source,
 		   g_strerror (errsv));
       return FALSE;
     }
-  else
-    source_is_dir = S_ISDIR (statbuf.st_mode);
 
+  source_is_dir = S_ISDIR (statbuf.st_mode);
   source_size = statbuf.st_size;
   
   destination_exist = FALSE;
@@ -2015,10 +2094,16 @@ g_local_file_move (GFile                  *source,
 	  /* Always fail on dirs, even with overwrite */
 	  if (S_ISDIR (statbuf.st_mode))
 	    {
-	      g_set_error (error,
-			   G_IO_ERROR,
-			   G_IO_ERROR_WOULD_MERGE,
-			   _("Can't move directory over directory"));
+	      if (source_is_dir)
+		g_set_error (error,
+			     G_IO_ERROR,
+			     G_IO_ERROR_WOULD_MERGE,
+			     _("Can't move directory over directory"));
+              else
+		g_set_error (error,
+			     G_IO_ERROR,
+			     G_IO_ERROR_IS_DIRECTORY,
+			     _("Can't copy over directory"));
 	      return FALSE;
 	    }
 	}
