@@ -65,12 +65,13 @@ g_union_volume_monitor_finalize (GObject *object)
 
   monitor = G_UNION_VOLUME_MONITOR (object);
 
-  while (monitor->monitors != NULL) {
-    child_monitor = monitor->monitors->data;
-    g_union_volume_monitor_remove_monitor (monitor, 
-                                           child_monitor);
-    g_object_unref (child_monitor);
-  }
+  while (monitor->monitors != NULL)
+    {
+      child_monitor = monitor->monitors->data;
+      g_union_volume_monitor_remove_monitor (monitor, 
+                                             child_monitor);
+      g_object_unref (child_monitor);
+    }
 
   
   if (G_OBJECT_CLASS (g_union_volume_monitor_parent_class)->finalize)
@@ -455,7 +456,7 @@ get_default_native_class (gpointer data)
  * instance on the first call.
  */
 static GNativeVolumeMonitorClass *
-get_native_class ()
+get_native_class (void)
 {
   static GOnce once_init = G_ONCE_INIT;
   GTypeClass *type_class;
@@ -463,7 +464,7 @@ get_native_class ()
   type_class = NULL;
   g_once (&once_init, (GThreadFunc)get_default_native_class, &type_class);
 
-  if (type_class == NULL && once_init.retval != G_TYPE_INVALID)
+  if (type_class == NULL && once_init.retval != GUINT_TO_POINTER(G_TYPE_INVALID))
     type_class = g_type_class_ref ((GType)once_init.retval);
   
   return (GNativeVolumeMonitorClass *)type_class;
@@ -649,7 +650,7 @@ g_volume_monitor_adopt_orphan_mount (GMount *mount)
 
       if (child_monitor_class->adopt_orphan_mount != NULL)
         {
-          volume = child_monitor_class->adopt_orphan_mount (mount);
+          volume = child_monitor_class->adopt_orphan_mount (mount, child_monitor);
           if (volume != NULL)
             break;
         }
